@@ -52,10 +52,9 @@ class CartesianLoader(VirtTestLoader):
         :param extra_params: extra configuration parameters
         :type extra_params: {str, str}
         """
+        extra_params = {} if not extra_params else extra_params
         self.logdir = extra_params.pop('logdir', ".")
         super().__init__(config, extra_params)
-        # VT is still behind taking on the new config structure (once done remove this)
-        self.config = vars(self.args)
 
     """parsing functionality"""
     def parse_objects(self, param_dict=None, object_strs=None, verbose=False):
@@ -312,7 +311,7 @@ class CartesianLoader(VirtTestLoader):
         if logging.getLogger('graph').level <= logging.DEBUG:
             parse_dir = os.path.join(self.logdir, "graph_parse")
             if not os.path.exists(parse_dir):
-                os.mkdir(parse_dir)
+                os.makedirs(parse_dir)
             step = 0
 
         while len(unresolved) > 0:
@@ -349,6 +348,7 @@ class CartesianLoader(VirtTestLoader):
                 if logging.getLogger('graph').level <= logging.DEBUG:
                     step += 1
                     graph.visualize(parse_dir, step)
+            test_node.validate()
 
         # finally build the shared root node from used test objects (roots)
         used_objects, used_roots = [], []
