@@ -45,7 +45,7 @@ class EmptyCartesianProduct(Exception):
         """
         Initialize an empty Cartesian product exception.
 
-        :param str message: additional message about the excaption
+        :param str message: additional message about the exception
         """
         message = "Empty Cartesian product of parameters!\n" + message
         message = "Check for self-excluding variants in your current configuration:\n" + message
@@ -58,9 +58,16 @@ class EmptyCartesianProduct(Exception):
 
 
 _devel_tp_folder = os.path.abspath(os.path.join(os.path.dirname(__file__), "..", "tp_folder"))
-suite_path = settings.get_value('i2n.common', 'suite_path', default=_devel_tp_folder)
+settings.register_option(section='i2n.common',
+                         key='suite_path',
+                         key_type=str,
+                         default=_devel_tp_folder,
+                         help_msg="Path to the test suite containing Cartesian variants and test scripts.")
+
+
 def custom_configs_dir():
     """Custom directory for all config files."""
+    suite_path = settings.as_dict().get('i2n.common.suite_path')
     return os.path.join(suite_path, "configs")
 
 
@@ -295,6 +302,8 @@ class Reparsable():
         parser = cartesian_config.Parser()
         hostname = os.environ.get("PREFIX", os.environ.get("HOSTNAME", "avocado"))
         parser.parse_string("hostname = %s\n" % hostname)
+        suite_path = settings.as_dict().get('i2n.common.suite_path')
+        parser.parse_string("suite_path = %s\n" % suite_path)
 
         for step in self.steps:
             if isinstance(step, ParsedFile):
