@@ -46,25 +46,75 @@ class CartesianRunner(TestRunner):
     description = 'Runs tests through a Cartesian graph traversal'
 
     """running functionality"""
-    def run_test_node(self, node):
+    def run_test_node(self, node, can_retry=False):
         """
-        A wrapper around the inherited :py:meth:`run_test`.
+        Run a node once, and optionally re-run it depending on the parameters.
 
         :param node: test node to run
         :type node: :py:class:`TestNode`
+        :param bool can_retry: whether this node can be re-run
         :returns: run status of :py:meth:`run_test`
         :rtype: bool
         :raises: :py:class:`AssertionError` if the ran test node contains no objects
 
-        This is a simple wrapper to provide some default arguments
-        for simplicity of invocation.
+        The retry parameters are `retry_attempts` and `retry_stop`. The first is
+        the maximum number of retries, and the second indicates when to stop retrying.
+        The possible combinations of these values are:
+
+        - `retry_stop = error`: retry until error or a maximum of `retry_attempts` number of times
+        - `retry_stop = success`: retry until success or a maximum of `retry_attempts` number of times
+        - `retry_stop = none`: retry a maximum of `retry_attempts` number of times
+
+        Only tests with the status of pass, warning, error or failure will be retried.
+        Other statuses will be ignored and the test will run only once.
+
+        This method also works as a convenience wrapper around :py:meth:`run_test`,
+        providing some default arguments.
         """
         if node.is_objectless():
             raise AssertionError("Cannot run test nodes not using any test objects, here %s" % node)
-        # TODO: in the future we better inherit from the Runner interface in
-        # avocado.core.plugin_interfaces and implement our own test node running
-        # like most of the other runners do
-        return self.run_test(self.job, self.result, node.get_test_factory(self.job), SimpleQueue(), set())
+
+        retry_stop = node.params.get("retry_stop", "none")
+        # ignore the retry parameters for nodes that cannot be re-run (need to run at least once)
+        runs_left = 1 + node.params.get_numeric("retry_attempts", 0) if can_retry else 1
+        # do not log when the user is not using the retry feature
+        if runs_left > 1:
+            logging.debug(f"Running test with retry_stop={retry_stop} and retry_attempts={runs_left}")
+        assert runs_left >= 1, "retry_attempts cannot be less than zero"
+        assert retry_stop in ["none", "error", "success"], "retry_stop must be one of 'none', 'error' or 'success'"
+
+        retval = False
+        original_shortname = node.params["shortname"]
+        for r in range(runs_left):
+            # appending a suffix to retries so we can tell them apart
+            if r > 0:
+                node.params["shortname"] = f"{original_shortname}.r{r}"
+
+            # TODO: in the future we better inherit from the Runner interface in
+            # avocado.core.plugin_interfaces and implement our own test node running
+            # like most of the other runners do
+            retval = self.run_test(self.job, node.get_test_factory(self.job), SimpleQueue(), set())
+
+            test_result = next((x for x in self.job.result.tests if x["name"].name == node.params["shortname"]))
+            test_status = test_result["status"]
+            if test_status not in ["PASS", "WARN", "ERROR", "FAIL"]:
+                # it doesn't make sense to retry with other status
+                logging.info(f"Will not attempt to retry test with status {test_status}")
+                break
+            if retry_stop == "success" and test_status in ["PASS", "WARN"]:
+                logging.info("Stopping after first successful run")
+                break
+            if retry_stop == "error" and test_status in ["ERROR", "FAIL"]:
+                logging.info("Stopping after first failed run")
+                break
+        node.params["shortname"] = original_shortname
+        # no need to log when test was not repeated
+        if runs_left > 1:
+            logging.info(f"Finished running test {r} times")
+        # FIX: as VT's retval is broken (always True), we fix its handling here
+        if test_status in ["ERROR", "FAIL"]:
+            retval = False
+        return retval
 
     def run_traversal(self, graph, params):
         """
@@ -93,7 +143,7 @@ class CartesianRunner(TestRunner):
         if logging.getLogger('graph').level <= logging.DEBUG:
             traverse_dir = os.path.join(self.job.logdir, "graph_traverse")
             if not os.path.exists(traverse_dir):
-                os.mkdir(traverse_dir)
+                os.makedirs(traverse_dir)
             step = 0
 
         traverse_path = [root]
@@ -152,25 +202,18 @@ class CartesianRunner(TestRunner):
                 step += 1
                 graph.visualize(traverse_dir, step)
 
-    def run_suite(self, job, result, test_suite, _variants, _timeout=0,
-                  _replay_map=None, _execution_order=None):
+    def run_suite(self, job, test_suite):
         """
         Run one or more tests and report with test result.
 
-        :param test_suite: a list of tests to run
-        :type test_suite: [(type, {str, str})]
-        :param variants: varianter iterator to produce test params
-        :type variants: :py:class:`avocado.core.varianter.Varianter`
-        :param int timeout: maximum amount of time (in seconds) to execute
-        :param replay_map: optional list to override test class based on test index
-        :type replay_map: [None or type]
-        :param str execution_order: Mode in which we should iterate through tests
-                                    and variants (if None will default to
-                                    :py:attr:`DEFAULT_EXECUTION_ORDER`
+        :param job: job that includes the test suite
+        :type test_suite: :py:class:`avocado.core.job.Job`
+        :param test_suite: test suite with some tests to run
+        :type test_suite: :py:class:`avocado.core.suite.TestSuite`
         :returns: a set with types of test failures
         :rtype: :py:class:`set`
         """
-        self.job, self.result = job, result
+        self.job = job
 
         graph = self._graph_from_suite(test_suite)
         summary = set()
@@ -183,7 +226,7 @@ class CartesianRunner(TestRunner):
             TEST_LOG.error('Job interrupted by ctrl+c.')
             summary.add('INTERRUPTED')
 
-        self.result.end_tests()
+        self.job.result.end_tests()
         self.job.funcatexit.run()
         signal.signal(signal.SIGTSTP, signal.SIG_IGN)
         return summary
@@ -206,7 +249,6 @@ class CartesianRunner(TestRunner):
         test_node = nodes[0]
         status = self.run_test_node(test_node)
 
-        # TODO: status is broken and is always true
         if status:
             try:
                 graph.load_setup_list(self.job.logdir)
@@ -216,7 +258,7 @@ class CartesianRunner(TestRunner):
                 graph.flag_children(flag=False)
 
         for node in graph.nodes:
-            self.result.cancelled += 1 if not node.should_run else 0
+            self.job.result.cancelled += 1 if not node.should_run else 0
 
     def run_create_node(self, graph, object_name):
         """
@@ -265,7 +307,6 @@ class CartesianRunner(TestRunner):
         test_node.params.update({"set_state": "", "skip_image_processing": "yes"})
         status = self.run_test_node(test_node)
 
-        # TODO: status is broken and is always true
         if not status:
             return
 
@@ -294,7 +335,6 @@ class CartesianRunner(TestRunner):
                                         ovrwrt_dict=setup_dict)
         status = self.run_test_node(TestNode("0q", install_config, test_node.objects))
 
-        # TODO: status is broken and is always true
         if not status:
             return
 
@@ -349,7 +389,7 @@ class CartesianRunner(TestRunner):
 
             else:
                 # finally, good old running of an actual test
-                self.run_test_node(test_node)
+                self.run_test_node(test_node, can_retry=True)
 
             for test_object in test_node.objects:
                 object_name = test_object.name
@@ -427,7 +467,7 @@ class CartesianRunner(TestRunner):
 
         # validate the test suite refers to the same test graph
         assert len(test_suite) == len(graph.nodes)
-        for node1, node2 in zip(test_suite, graph.nodes):
+        for node1, node2 in zip(test_suite.tests, graph.nodes):
             assert node1 == node2.get_test_factory()
 
         return graph
